@@ -83,6 +83,8 @@ def augments(cls_cpp: Type[Any]):
 
     def class_augment(cls, cls_cpp=cls_cpp):
         for name, member in inspect.getmembers(cls):
+            if hasattr(cls_cpp, name):  # For PyPy: don't replace existing methods
+                continue
             if inspect.isfunction(member):
                 member.__qualname__ = member.__qualname__.replace(
                     cls.__name__, cls_cpp.__name__
@@ -113,6 +115,7 @@ def _single_page_pdf(page) -> bytes:
 
 def _mudraw(buffer, fmt) -> bytes:
     """Use mupdf draw to rasterize the PDF in the memory buffer"""
+    # mudraw cannot read from stdin so NamedTemporaryFile is required
     with NamedTemporaryFile(suffix='.pdf') as tmp_in:
         tmp_in.write(buffer)
         tmp_in.seek(0)
@@ -124,14 +127,12 @@ def _mudraw(buffer, fmt) -> bytes:
             stderr=PIPE,
             check=True,
         )
-        if proc.stderr:
-            raise RuntimeError(proc.stderr.decode())
         return proc.stdout
 
 
 @augments(Object)
 class Extend_Object:
-    def _repr_mimebundle_(self, include, exclude, **kwargs):
+    def _repr_mimebundle_(self, include=None, exclude=None):
         """Present options to IPython for rich display of this object
 
         See https://ipython.readthedocs.io/en/stable/config/integrating.html#rich-display
@@ -142,7 +143,7 @@ class Extend_Object:
             and Name.Type in self
             and self.Type == Name.Page
         ):
-            return Page(self)._repr_mimebundle_(include, exclude, **kwargs)
+            return Page(self)._repr_mimebundle_(include, exclude)
         return None
 
     def _ipython_key_completions_(self):
@@ -272,7 +273,7 @@ class Extend_Pdf:
         warn("Pdf.root is deprecated; use Pdf.Root", category=DeprecationWarning)
         return self.Root
 
-    def _repr_mimebundle_(self, **_kwargs):
+    def _repr_mimebundle_(self, include=None, exclude=None):
         """
         Present options to IPython or Jupyter for rich display of this object
 
@@ -286,6 +287,48 @@ class Extend_Pdf:
         data = {'application/pdf': bio.read()}
         return data
 
+    @property
+    def docinfo(self) -> Dictionary:
+        """
+        Access the (deprecated) document information dictionary.
+
+        The document information dictionary is a brief metadata record that can
+        store some information about the origin of a PDF. It is deprecated and
+        removed in the PDF 2.0 specification (not deprecated from the
+        perspective of pikepdf). Use the ``.open_metadata()`` API instead, which
+        will edit the modern (and unfortunately, more complicated) XMP metadata
+        object and synchronize changes to the document information dictionary.
+
+        This property simplifies access to the actual document information
+        dictionary and ensures that it is created correctly if it needs to be
+        created.
+
+        A new, empty dictionary will be created if this property is accessed
+        and dictionary does not exist. (This is to ensure that convenient code
+        like ``pdf.docinfo[Name.Title] = "Title"`` will work when the dictionary
+        does not exist at all.)
+
+        You can delete the document information dictionary by deleting this property,
+        ``del pdf.docinfo``. Note that accessing the property after deleting it
+        will re-create with a new, empty dictionary.
+        """
+        if Name.Info not in self.trailer:
+            self.trailer.Info = self.make_indirect(Dictionary())
+        return self.trailer.Info
+
+    @docinfo.setter
+    def docinfo(self, new_docinfo: Dictionary):
+        if not new_docinfo.is_indirect:
+            raise ValueError(
+                "docinfo must be an indirect object - use Pdf.make_indirect"
+            )
+        self.trailer.Info = new_docinfo
+
+    @docinfo.deleter
+    def docinfo(self):
+        if Name.Info in self.trailer:
+            del self.trailer.Info
+
     def open_metadata(
         self,
         set_pikepdf_as_editor: bool = True,
@@ -374,14 +417,8 @@ class Extend_Pdf:
         """
         Create a new pikepdf.Stream object that is attached to this PDF.
 
-        Args:
-            data (bytes): Binary data for the stream object
-            d: Dictionary portion of the stream object
-            kwargs: Keyword arguments to define the dictionary. Do not set
-                /Filter or /Length here as pikepdf will manage these.
-
-        Example:
-            pdf.make_stream(b"Binary data here", Type=Name.XObject, Subtype=Name.Image)
+        See:
+            :meth:`pikepdf.Stream.__new__`
 
         """
         return Stream(self, data, d, **kwargs)
@@ -459,10 +496,7 @@ class Extend_Pdf:
             b"%%EOF\n"
         )
 
-        if self.filename:
-            description = "closed file: " + self.filename
-        else:
-            description = "closed object"
+        description = "closed file: " + self.filename
         self._process(description, EMPTY_PDF)
         if getattr(self, '_tmp_stream', None):
             self._tmp_stream.close()
@@ -612,7 +646,7 @@ class Extend_Pdf:
             self.Root.PageMode = Name.UseAttachments
 
     def save(
-        self,
+        self,  # TODO mandatory kwargs
         filename_or_stream: Union[Path, str, BinaryIO, None] = None,
         static_id: bool = False,
         preserve_pdfa: bool = True,
@@ -627,6 +661,7 @@ class Extend_Pdf:
         qdf: bool = False,
         progress: Callable[[int], None] = None,
         encryption: Optional[Union[Encryption, bool]] = None,
+        recompress_flate: bool = False,
     ) -> None:
         """
         Save all modifications to this :class:`pikepdf.Pdf`.
@@ -686,6 +721,12 @@ class Extend_Pdf:
                 to encode stream objects. See documentation for
                 ``StreamDecodeLevel``.
 
+            recompress_flate: When disabled (the default), qpdf does not
+                uncompress and recompress streams compressed with the Flate
+                compression algorithm. If True, pikepdf will instruct qpdf to
+                do this, which may be useful if recompressing streams to a
+                higher compression level.
+
             normalize_content: Enables parsing and reformatting the
                 content stream within PDFs. This may debugging PDFs easier.
 
@@ -753,10 +794,11 @@ class Extend_Pdf:
             progress=progress,
             encryption=encryption,
             samefile_check=getattr(self, '_tmp_stream', None) is None,
+            recompress_flate=recompress_flate,
         )
 
     @staticmethod
-    def open(
+    def open(  # TODO mandatory kwargs
         filename_or_stream: Union[Path, str, BinaryIO],
         password: Union[str, bytes] = "",
         hex_password: bool = False,
@@ -847,6 +889,16 @@ class Extend_Pdf:
                 usable.
             FileNotFoundError: If the file was not found.
         """
+        if isinstance(filename_or_stream, bytes) and filename_or_stream.startswith(
+            b'%PDF-'
+        ):
+            warn(
+                "It looks like you called with Pdf.open(data) with a bytes-like object "
+                "containing a PDF. This will probably fail because this function "
+                "expects a filename or opened file-like object. Instead, please use "
+                "Pdf.open(BytesIO(data))."
+            )
+
         tmp_stream, original_filename = None, False
         if allow_overwriting_input:
             try:
@@ -977,7 +1029,7 @@ class Extend_Page:
             The name of the object.
 
         Example:
-            resource_name = Page(pdf.pages[0]).add_resource(formxobj, Name.XObject)
+            >>> resource_name = Page(pdf.pages[0]).add_resource(formxobj, Name.XObject)
         """
         if not Name.Resources in self.obj:
             self.obj.Resources = Dictionary()
@@ -1008,7 +1060,7 @@ class Extend_Page:
     def __repr__(self):
         return repr(self.obj).replace('Dictionary', 'Page')
 
-    def _repr_mimebundle_(self, include, exclude, **_kwargs):
+    def _repr_mimebundle_(self, include=None, exclude=None):
         data = {}
         bundle = {'application/pdf', 'image/png'}
         if include:
